@@ -85,37 +85,37 @@
 
 // Type indices
 enum : int {
-    SBK_QtSqlQSQL_IDX                                        = 1,
     SBK_QSQL_LOCATION_IDX                                    = 2,
     SBK_QSQL_PARAMTYPEFLAG_IDX                               = 4,
     SBK_QFLAGS_QSQL_PARAMTYPEFLAG_IDX                        = 0,
     SBK_QSQL_TABLETYPE_IDX                                   = 5,
     SBK_QSQL_NUMERICALPRECISIONPOLICY_IDX                    = 3,
+    SBK_QtSqlQSQL_IDX                                        = 1,
     SBK_QSQLDATABASE_IDX                                     = 6,
-    SBK_QSQLDRIVER_IDX                                       = 7,
     SBK_QSQLDRIVER_DRIVERFEATURE_IDX                         = 9,
     SBK_QSQLDRIVER_STATEMENTTYPE_IDX                         = 12,
     SBK_QSQLDRIVER_IDENTIFIERTYPE_IDX                        = 10,
     SBK_QSQLDRIVER_NOTIFICATIONSOURCE_IDX                    = 11,
     SBK_QSQLDRIVER_DBMSTYPE_IDX                              = 8,
+    SBK_QSQLDRIVER_IDX                                       = 7,
     SBK_QSQLDRIVERCREATORBASE_IDX                            = 13,
-    SBK_QSQLERROR_IDX                                        = 14,
     SBK_QSQLERROR_ERRORTYPE_IDX                              = 15,
-    SBK_QSQLFIELD_IDX                                        = 16,
+    SBK_QSQLERROR_IDX                                        = 14,
     SBK_QSQLFIELD_REQUIREDSTATUS_IDX                         = 17,
+    SBK_QSQLFIELD_IDX                                        = 16,
     SBK_QSQLINDEX_IDX                                        = 18,
-    SBK_QSQLQUERY_IDX                                        = 19,
     SBK_QSQLQUERY_BATCHEXECUTIONMODE_IDX                     = 20,
+    SBK_QSQLQUERY_IDX                                        = 19,
     SBK_QSQLQUERYMODEL_IDX                                   = 21,
     SBK_QSQLRECORD_IDX                                       = 22,
     SBK_QSQLRELATION_IDX                                     = 23,
     SBK_QSQLRELATIONALDELEGATE_IDX                           = 24,
-    SBK_QSQLRELATIONALTABLEMODEL_IDX                         = 25,
     SBK_QSQLRELATIONALTABLEMODEL_JOINMODE_IDX                = 26,
-    SBK_QSQLRESULT_IDX                                       = 27,
+    SBK_QSQLRELATIONALTABLEMODEL_IDX                         = 25,
     SBK_QSQLRESULT_BINDINGSYNTAX_IDX                         = 28,
-    SBK_QSQLTABLEMODEL_IDX                                   = 29,
+    SBK_QSQLRESULT_IDX                                       = 27,
     SBK_QSQLTABLEMODEL_EDITSTRATEGY_IDX                      = 30,
+    SBK_QSQLTABLEMODEL_IDX                                   = 29,
     SBK_QtSql_IDX_COUNT                                      = 31
 };
 // This variable stores all Python types exported by this module.
@@ -132,14 +132,13 @@ enum : int {
     SBK_QTSQL_QLIST_QOBJECTPTR_IDX                           = 0, // const QList<QObject* > &
     SBK_QTSQL_QLIST_QBYTEARRAY_IDX                           = 1, // QList<QByteArray >
     SBK_QTSQL_QMAP_QSTRING_QVARIANT_IDX                      = 2, // QMap<QString,QVariant >
-    SBK_QTSQL_QVECTOR_INT_IDX                                = 3, // const QVector<int > &
-    SBK_QTSQL_QHASH_INT_QBYTEARRAY_IDX                       = 4, // const QHash<int,QByteArray > &
-    SBK_QTSQL_QMAP_INT_QVARIANT_IDX                          = 5, // QMap<int,QVariant >
-    SBK_QTSQL_QLIST_QPERSISTENTMODELINDEX_IDX                = 6, // const QList<QPersistentModelIndex > &
-    SBK_QTSQL_QVECTOR_QVARIANT_IDX                           = 7, // QVector<QVariant > &
-    SBK_QTSQL_QLIST_QVARIANT_IDX                             = 8, // QList<QVariant >
-    SBK_QTSQL_QLIST_QSTRING_IDX                              = 9, // QList<QString >
-    SBK_QtSql_CONVERTERS_IDX_COUNT                           = 10
+    SBK_QTSQL_QMAP_INT_QVARIANT_IDX                          = 3, // QMap<int,QVariant >
+    SBK_QTSQL_QHASH_INT_QBYTEARRAY_IDX                       = 4, // QHash<int,QByteArray >
+    SBK_QTSQL_QVECTOR_INT_IDX                                = 5, // QVector<int >
+    SBK_QTSQL_QVECTOR_QVARIANT_IDX                           = 6, // QVector<QVariant > &
+    SBK_QTSQL_QLIST_QVARIANT_IDX                             = 7, // QList<QVariant >
+    SBK_QTSQL_QLIST_QSTRING_IDX                              = 8, // QList<QString >
+    SBK_QtSql_CONVERTERS_IDX_COUNT                           = 9
 };
 // Macros for type check
 
